==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/features/encrypt/core/src/test/java/org/apache/shardingsphere/encrypt/metadata/reviser/column/EncryptColumnNameReviserTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.encrypt.metadata.reviser.column;

import org.apache.shardingsphere.encrypt.rule.table.EncryptTable;
import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

class EncryptColumnNameReviserTest {
    
    @Test
    void assertRevise() {
        EncryptTable encryptTable = mock(EncryptTable.class);
        EncryptColumnNameReviser encryptColumnNameReviser = new EncryptColumnNameReviser(encryptTable);
        when(encryptTable.isCipherColumn("Cipher")).thenReturn(true);
        when(encryptTable.getLogicColumnByCipherColumn("Cipher")).thenReturn("Logic");
        assertThat(encryptColumnNameReviser.revise("Cipher"), is("Logic"));
        assertThat(encryptColumnNameReviser.revise("NonCipher"), is("NonCipher"));
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/features/encrypt/core/src/test/java/org/apache/shardingsphere/encrypt/metadata/reviser/column/EncryptColumnNameReviserTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.encrypt.metadata.reviser.column;

import org.apache.shardingsphere.encrypt.rule.table.EncryptTable;
import org.junit.jupiter.api.Test;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

class EncryptColumnNameReviserTest {
    
    @Test
    void assertRevise() {
        EncryptTable encryptTable = mock(EncryptTable.class);
        EncryptColumnNameReviser encryptColumnNameReviser = new EncryptColumnNameReviser(encryptTable);
        when(encryptTable.isCipherColumn("Cipher")).thenReturn(true);
        when(encryptTable.getLogicColumnByCipherColumn("Cipher")).thenReturn("Logic");
        assertThat(encryptColumnNameReviser.revise("Cipher"), is("Logic"));
        assertThat(encryptColumnNameReviser.revise("NonCipher"), is("NonCipher"));
    }
}
